@@ -1,9 +1,11 @@
-#!/usr/local/bin/ruby -w
+#!/usr/bin/env ruby
+
+$VERBOSE = true
 
 require "test/unit"
-require "rss/parser"
+require "rss"
 
-test_file = "test/test_*"
+test_file = "#{File.dirname(__FILE__)}/test_*.rb"
 case ARGV.first
 when /\A--\z/
   ARGV.shift
@@ -14,6 +16,8 @@ end
 
 $:.unshift(File.join(File.expand_path("."), "lib"))
 $:.unshift(File.join(File.expand_path("."), "test"))
+require 'test-unit-ext'
+
 Dir.glob(test_file) do |file|
   require file
 end
@@ -22,6 +26,9 @@ argv = ARGV.dup
 unless argv.find {|opt| /\A(?:-v|--verbose=)/ =~ opt}
   argv << "--verbose=n"
 end
+unless argv.find {|opt| /\A--(?:no-)priority/ =~ opt}
+  argv << "--priority"
+end
 
 RSS::AVAILABLE_PARSERS.each do |parser|
   puts "------------------------------------"
